cosmpy.protos.cosmos.upgrade.v1beta1 package — cosmpy documentation

# cosmpy.protos.cosmos.upgrade.v1beta1 package

## Submodules

## cosmpy.protos.cosmos.upgrade.v1beta1.query_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.upgrade.v1beta1.query_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.cosmos.upgrade.v1beta1.query_pb2_grpc.Query

  Bases: `object`

  Query defines the gRPC upgrade querier service.

  static AppliedPlan(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static CurrentPlan(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static UpgradedConsensusState(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.cosmos.upgrade.v1beta1.query_pb2_grpc.QueryServicer

  Bases: `object`

  Query defines the gRPC upgrade querier service.

  AppliedPlan(request, context)

    AppliedPlan queries a previously applied upgrade plan by its name.

  CurrentPlan(request, context)

    CurrentPlan queries the current upgrade plan.

  UpgradedConsensusState(request, context)

    UpgradedConsensusState queries the consensus state that will serve as a trusted kernel for the next version of this chain. It will only be stored at the last height of this chain. UpgradedConsensusState RPC not supported with legacy querier

class cosmpy.protos.cosmos.upgrade.v1beta1.query_pb2_grpc.QueryStub(channel)

  Bases: `object`

  Query defines the gRPC upgrade querier service.

cosmpy.protos.cosmos.upgrade.v1beta1.query_pb2_grpc.add_QueryServicer_to_server(servicer, server)

## cosmpy.protos.cosmos.upgrade.v1beta1.upgrade_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.upgrade.v1beta1.upgrade_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## Module contents